;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "auto-compile" "20251111.1802"
  "Automatically compile Emacs Lisp libraries."
  '((emacs "27.1"))
  :url "https://github.com/emacscollective/auto-compile"
  :commit "7d314cc13515a1bd6ded29e69a9d4be4aff205c3"
  :revdesc "7d314cc13515"
  :keywords '("compile" "convenience" "lisp")
  :authors '(("Jonas Bernoulli" . "emacs.auto-compile@jonas.bernoulli.dev"))
  :maintainers '(("Jonas Bernoulli" . "emacs.auto-compile@jonas.bernoulli.dev")))
